==> flutter_tapresearch-0.0.2.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_tapresearch/flutter_tapresearch.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    TapResearch.instance
        .init(
            apiToken: 'api_token',
            userId: 'user_id')
        .then((_) => TapResearch.instance
            .initPlacement(placementId: 'placement_id'));
    TapResearch.instance
        .setTapResearchDidReceiveRewardListener(onTapResearchReward);
    TapResearch.instance.setTapResearchIsSurveyWallAvailableListener(
        onTapResearchSurveyAvailable);
    TapResearch.instance
        .setTapResearchSurveyWallOpenedListener(onTapResearchOpened);
    TapResearch.instance
        .setTapResearchSurveyWallDismissedListener(onTapResearchDismissed);
    super.initState();
  }

  void onTapResearchReward(int quantity) {
    print('TR: $quantity');
  }

  void onTapResearchSurveyAvailable(int survey) {
    print('TR: $survey');
  }

  void onTapResearchDismissed() {
    print('TR: closed');
  }

  void onTapResearchOpened() {
    print('TR: opened');
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('TapResearch example app'),
        ),
        body: Center(
            child: RaisedButton(
                child: Text("Launch TapResearch"),
                onPressed: () {
                  TapResearch.instance.showSurveyWall();
                })),
      ),
    );
  }
}

==> flutter_tapresearch-1.0.0.tar.gz: example/lib/main.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_tapresearch/flutter_tapresearch.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  @override
  void initState() {
    TapResearch.instance.init(apiToken: 'api_token', userId: 'user_id').then((value) =>     TapResearch.instance.initPlacement(placementId: 'placement_id'));
    TapResearch.instance.setDidReceiveRewardListener(onTapResearchReward);
    TapResearch.instance
        .setIsSurveyWallAvailableListener(onTapResearchSurveyAvailable);
    TapResearch.instance.setSurveyWallOpenedListener(onTapResearchOpened);
    TapResearch.instance.setSurveyWallDismissedListener(onTapResearchDismissed);
    super.initState();
  }

  void onTapResearchReward(int quantity) {
    print('TR: $quantity');
  }

  void onTapResearchSurveyAvailable(int survey) {
    print('TR: $survey');
  }

  void onTapResearchDismissed() {
    print('TR: closed');
  }

  void onTapResearchOpened() {
    print('TR: opened');
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('TapResearch example app'),
        ),
        body: Center(
            child: RaisedButton(
                child: Text("Launch TapResearch"),
                onPressed: () {
                  TapResearch.instance.showSurveyWall();
                })),
      ),
    );
  }
}
